==> dl.php?src=linea21_1_6.zip: linea21/yellowpages/det.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage yellowpages
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

include_once(override('../yellowpages/display.php', THEME_ADMIN_PATH)); 


if(isset($_GET['state'])) {
  $state=$_GET['state'];
  if(isset($_POST['id']))	$yp_id=$_POST['id'];
  if(isset($_GET['id']))	$yp_id=$_GET['id'];
  $yp_object= new yellowpages;
  $result_update=$yp_object->StateYellowPages($yp_id, 'P', $sql_object);
  $link_confirm="confirm.php?rub=".$rub."&todo=mod&id=".$yp_id;
  if (ALERT_DIRECTORY==1) {
    include_once(override('../yellowpages/mail_actions.php'));
    include_once('../mail/template.php');
  }
  echo $result_update;
  if($result_update) header("Location: ".$link_confirm);
  else  system_error();
}

if(!isset($_GET['id']) && !isset($_POST['id'])) {
  $id="1";
} else {
  if(isset($_POST['id']))	$id=$_POST['id'];
  if(isset($_GET['id']))	$id=$_GET['id'];
}

$req_det= SQL_getdetyp($id);
$result=$sql_object->DBSelect($req_det);
$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_det_theme="index.php?rub=theme&amp;todo=det&amp;id=";
$link_sup=$rub_link."&amp;todo=sup&amp;id=";
$link_mod=$rub_link."&amp;todo=mod&amp;id=";
$navtitle=_t('yp','det')." : ".$result[0]['yellowp_name'];
$display_title=formatTitleh2($result[0]['yellowp_name']);
?>
<div id="chemin">
  <ul>
  	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
  	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','yellowpages')?></a></li>
  	<li><span><?php echo formatnavTitle($navtitle); ?></span></li>
  </ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php
$link_det_state=$rub_link."&todo=det&state=".$result[0]['yellowp_statut']."&amp;id=";
if ($result[0]['yellowp_statut']=='D') {  ?>
<div class="mod_link">
	<a href="<?php echo $link_det_state.$id ;?>"><?php echo _t('yp','confirmation');?></a>
</div>
<br class="brendstep" />
<?php } ?>
<h2><?php  echo $display_title; ?></h2>
<?php echo "<a href=\"".$link_sup.$id."\" title=\""._t('yp','sup')."\" class=\"ico_sup2\">"; ?></a>
<?php echo "<a href=\"".$link_mod.$id."\" title=\""._t('yp','mod')."\" class=\"ico_mod2\">"; ?></a>

<dl class="dl2">
	<dt><?php echo mb_ucfirst(_t('yp','theme')); ?> :</dt>
	<dd><?php
	if ($result[0]['yellowp_theme']<>-1) echo "<a href=\"".$link_det_theme.$result[0]['yellowp_theme']."\" title=\"".formatText($result[0]['theme_name'], '2HTML')."\">".formatText($result[0]['theme_name'], '2HTML')."</a></dd>";
	else echo _t('yp','notheme')."</dd>";
	?>
	<dt><?php echo mb_ucfirst(_t('yp','name2')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_name']), '2HTML'); ?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','activity')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_activity']), '2HTML'); ?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','street')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_street']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','postal_code')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_postal_code']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','city')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_city']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','phone')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_phone']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','fax'));?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_fax']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','email')); ?> :</dt>
	<dd><?php echo "<a href=\"mailto:".$result[0]['yellowp_email']."\" title=\"" .formatText($result[0]['yellowp_email'], '2HTML')."\">" .formatText($result[0]['yellowp_email'], '2HTML')."</a>";?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','website')); ?> :</dt>
	<dd><?php
	if ($result[0]['yellowp_website']<>"")
	echo "<a href=\"".$result[0]['yellowp_website']."\" title=\"".formatText($result[0]['yellowp_website'], '2HTML')."\">".formatText($result[0]['yellowp_website'], '2HTML')."</a></dd>";
	else    echo formatText(empty_nc($result[0]['yellowp_website']), '2HTML')."</dd>";

	?>
	<dt><?php echo mb_ucfirst(_t('divers','date_crea')); ?> :</dt>
	<dd><?php echo $result[0]['yellowp_date_crea'];?></dd>
	<dt><?php echo mb_ucfirst(_t('divers','statut')); ?> :</dt>
	<dd><?php if ($result[0]['yellowp_statut']=='D') {
	  echo mb_ucfirst(_t('yp','draft'));
	}
	else echo display_statut($result[0]['yellowp_statut']);?></dd>

</dl>
<?php echo generateMap('map', $result, 16) ; ?>
</div>
<?php include_once(override($dir.'/help.php', THEME_ADMIN_PATH)); ?>
</div>

==> dl.php?src=linea21_1_7.zip: linea21/yellowpages/det.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage yellowpages
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

include_once(override('../yellowpages/display.php', THEME_ADMIN_PATH)); 


if(isset($_GET['state'])) {
  $state=$_GET['state'];
  if(isset($_POST['id']))	$yp_id=$_POST['id'];
  if(isset($_GET['id']))	$yp_id=$_GET['id'];
  $yp_object= new yellowpages;
  $result_update=$yp_object->StateYellowPages($yp_id, 'P', $sql_object);
  $link_confirm="confirm.php?rub=".$rub."&todo=mod&id=".$yp_id;
  if (ALERT_DIRECTORY==1) {
  	$todo_mail = 'confirm_entry';
  	$link = HrefMaker(array('rub' => $GLOBALS['links'][U_L]['directory-detail']['linkvalue'], 'id' => $yp_id));
  	$full_link = SITE_ROOT_URL. 'public/'.$link;
  	
    include_once(override('../yellowpages/mail_actions.php'));
    include_once(override('../mail/template.php'));
  }
  echo $result_update;
  if($result_update) header("Location: ".$link_confirm);
  else  system_error();
}

if(!isset($_GET['id']) && !isset($_POST['id'])) {
  $id="1";
} else {
  if(isset($_POST['id']))	$id=$_POST['id'];
  if(isset($_GET['id']))	$id=$_GET['id'];
}

$req_det= SQL_getdetyp($id);
$result=$sql_object->DBSelect($req_det);
$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_det_theme="index.php?rub=theme&amp;todo=det&amp;id=";
$link_sup=$rub_link."&amp;todo=sup&amp;id=";
$link_mod=$rub_link."&amp;todo=mod&amp;id=";
$navtitle=_t('yp','det')." : ".$result[0]['yellowp_name'];
$display_title=formatTitleh2($result[0]['yellowp_name']);
?>
<div id="chemin">
  <ul>
  	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
  	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','yellowpages')?></a></li>
  	<li><span><?php echo formatnavTitle($navtitle); ?></span></li>
  </ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php
$link_det_state=$rub_link."&todo=det&state=".$result[0]['yellowp_statut']."&amp;id=";
if ($result[0]['yellowp_statut']=='D') {  ?>
<div class="mod_link">
	<a href="<?php echo $link_det_state.$id ;?>"><?php echo _t('yp','confirmation');?></a>
</div>
<br class="brendstep" />
<?php } ?>
<h2><?php  echo $display_title; ?></h2>
<?php echo "<a href=\"".$link_sup.$id."\" title=\""._t('yp','sup')."\" class=\"ico_sup2\">"; ?><i class="icon-trash"></i><span><?php echo _t('yp','sup'); ?></span></a>
<?php echo "<a href=\"".$link_mod.$id."\" title=\""._t('yp','mod')."\" class=\"ico_mod2\">"; ?><i class="icon-pencil"></i><span><?php echo _t('yp','mod'); ?></span></a>

<dl class="dl2">
	<dt><?php echo mb_ucfirst(_t('yp','theme')); ?> :</dt>
	<dd><?php
	if ($result[0]['yellowp_theme']<>-1) echo "<a href=\"".$link_det_theme.$result[0]['yellowp_theme']."\" title=\"".formatText($result[0]['theme_name'], '2HTML')."\">".formatText($result[0]['theme_name'], '2HTML')."</a></dd>";
	else echo _t('yp','notheme')."</dd>";
	?>
	<dt><?php echo mb_ucfirst(_t('yp','name2')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_name']), '2HTML'); ?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','activity')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_activity']), '2HTML'); ?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','street')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_street']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','postal_code')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_postal_code']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','city')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_city']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','phone')); ?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_phone']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','fax'));?> :</dt>
	<dd><?php echo formatText(empty_nc($result[0]['yellowp_fax']), '2HTML');?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','email')); ?> :</dt>
	<dd><?php echo "<a href=\"mailto:".$result[0]['yellowp_email']."\" title=\"" .formatText($result[0]['yellowp_email'], '2HTML')."\">" .formatText($result[0]['yellowp_email'], '2HTML')."</a>";?></dd>
	<dt><?php echo mb_ucfirst(_t('yp','website')); ?> :</dt>
	<dd><?php
	if ($result[0]['yellowp_website']<>"")
	echo "<a href=\"".$result[0]['yellowp_website']."\" title=\"".formatText($result[0]['yellowp_website'], '2HTML')."\">".formatText($result[0]['yellowp_website'], '2HTML')."</a></dd>";
	else    echo formatText(empty_nc($result[0]['yellowp_website']), '2HTML')."</dd>";

	?>
	<dt><?php echo mb_ucfirst(_t('divers','date_crea')); ?> :</dt>
	<dd><?php echo $result[0]['yellowp_date_crea'];?></dd>
	<dt><?php echo mb_ucfirst(_t('divers','statut')); ?> :</dt>
	<dd><?php if ($result[0]['yellowp_statut']=='D') {
	  echo mb_ucfirst(_t('yp','draft'));
	}
	else echo display_statut($result[0]['yellowp_statut']);?></dd>

</dl>
<?php echo generateMap('map', $result, 16) ; ?>
</div>
<?php include_once(override($dir.'/help.php', THEME_ADMIN_PATH)); ?>
</div>
